#ifndef BIORBD_CONFIG_H
#define BIORBD_CONFIG_H

//Some day, if Eigen can be compile in DLL
//#ifdef _WIN32
//#  ifdef BIORBD_API_EXPORTS
//#    define BIORBD_API __declspec(dllexport)
//#  else
//#    define BIORBD_API __declspec(dllimport)
//#  endif
//#else
//#  define BIORBD_API
//#endif
#define BIORBD_API

#ifdef _WIN32
#define _ENABLE_EXTENDED_ALIGNED_STORAGE
#endif

// Choice of modules
#define MODULE_ACTUATORS
#define MODULE_MUSCLES

// Define some skip if ones doesn't want to compile them
/* #undef SKIP_KALMAN */
#define SKIP_STATIC_OPTIM
/* #undef SKIP_LONG_TESTS */

#ifndef _WIN32
#ifndef NAN
    //static const unsigned long __nan[2] = {0xffffffff, 0x7fffffff};
    #define NAN (*(const float *) __nan)
#endif // NAN
    
#endif // _WIN32
#endif // BIORBD_CONFIG_H
